@@ -3,7 +3,7 @@ import json
 import logging
 from asyncio import AbstractEventLoop
 from logging import Logger
-from typing import Optional, BinaryIO, Dict, Sequence, Union, List
+from typing import Optional, BinaryIO, Dict, Sequence, Union, List, Any
 
 import aiohttp
 from aiohttp import ClientSession
@@ -50,12 +50,13 @@ async def _request_with_session(
     api_url: str,
     req_args: dict,
     # set the default to an empty array for legacy clients
-    retry_handlers: List[AsyncRetryHandler] = [],
-) -> Dict[str, any]:
+    retry_handlers: Optional[List[AsyncRetryHandler]] = None,
+) -> Dict[str, Any]:
     """Submit the HTTP request with the running session or a new session.
     Returns:
         A dictionary of the response data.
     """
+    retry_handlers = retry_handlers if retry_handlers is not None else []
     session = None
     use_running_session = current_session and not current_session.closed
     if use_running_session:
@@ -67,7 +68,7 @@ async def _request_with_session(
         )
 
     last_error: Optional[Exception] = None
-    resp: Optional[Dict[str, any]] = None
+    resp: Optional[Dict[str, Any]] = None
     try:
         retry_request = RetryHttpRequest(
             method=http_verb,
@@ -90,14 +91,10 @@ async def _request_with_session(
                 def convert_params(values: dict) -> dict:
                     if not values or not isinstance(values, dict):
                         return {}
-                    return {
-                        k: ("(bytes)" if isinstance(v, bytes) else v)
-                        for k, v in values.items()
-                    }
+                    return {k: ("(bytes)" if isinstance(v, bytes) else v) for k, v in values.items()}
 
                 headers = {
-                    k: "(redacted)" if k.lower() == "authorization" else v
-                    for k, v in req_args.get("headers", {}).items()
+                    k: "(redacted)" if k.lower() == "authorization" else v for k, v in req_args.get("headers", {}).items()
                 }
                 logger.debug(
                     f"Sending a request - url: {http_verb} {api_url}, "
@@ -129,9 +126,7 @@ async def _request_with_session(
                                 body=data,
                             )
                         except aiohttp.ContentTypeError:
-                            logger.debug(
-                                f"No response data returned from the following API call: {api_url}."
-                            )
+                            logger.debug(f"No response data returned from the following API call: {api_url}.")
                         except json.decoder.JSONDecodeError:
                             try:
                                 body: str = await res.text()
@@ -143,24 +138,29 @@ async def _request_with_session(
                                     res,
                                 )
 
-                    if res.status == 429:
-                        for handler in retry_handlers:
-                            if await handler.can_retry_async(
+                    if logger.level <= logging.DEBUG:
+                        body = data if isinstance(data, dict) else "(binary)"
+                        logger.debug(
+                            "Received the following response - "
+                            f"status: {res.status}, "
+                            f"headers: {dict(res.headers)}, "
+                            f"body: {body}"
+                        )
+
+                    for handler in retry_handlers:
+                        if await handler.can_retry_async(
+                            state=retry_state,
+                            request=retry_request,
+                            response=retry_response,
+                        ):
+                            if logger.level <= logging.DEBUG:
+                                logger.info(f"A retry handler found: {type(handler).__name__} " f"for {http_verb} {api_url}")
+                            await handler.prepare_for_next_attempt_async(
                                 state=retry_state,
                                 request=retry_request,
                                 response=retry_response,
-                            ):
-                                if logger.level <= logging.DEBUG:
-                                    logger.info(
-                                        f"A retry handler found: {type(handler).__name__} "
-                                        f"for {http_verb} {api_url} - rate_limited"
-                                    )
-                                await handler.prepare_for_next_attempt_async(
-                                    state=retry_state,
-                                    request=retry_request,
-                                    response=retry_response,
-                                )
-                                break
+                            )
+                            break
 
                     if retry_state.next_attempt_requested is False:
                         response = {
@@ -181,8 +181,7 @@ async def _request_with_session(
                     ):
                         if logger.level <= logging.DEBUG:
                             logger.info(
-                                f"A retry handler found: {type(handler).__name__} "
-                                f"for {http_verb} {api_url} - {e}"
+                                f"A retry handler found: {type(handler).__name__} " f"for {http_verb} {api_url} - {e}"
                             )
                         await handler.prepare_for_next_attempt_async(
                             state=retry_state,
